@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.001-TRIAL-11-g53ec9c7
+package Dist::Zilla::Plugin::RewriteVersion::Transitional; # git description: v0.002-12-g002d225
 # ABSTRACT: ease the transition to [RewriteVersion] in your distribution
 # KEYWORDS: plugin version rewrite munge module
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.002';
+
+our $VERSION = '0.003';
 use Moose;
 extends 'Dist::Zilla::Plugin::RewriteVersion';
 with 'Dist::Zilla::Role::InsertVersion';
@@ -34,6 +35,7 @@ has _fallback_version_provider_obj => (
             %{ $self->_fallback_version_provider_args },
         );
     },
+    predicate => '_using_fallback_version_provider',
 );
 
 around BUILDARGS => sub
@@ -58,6 +60,9 @@ around dump_config => sub
         map { $_ => $self->$_ } qw(fallback_version_provider _fallback_version_provider_args),
     };
 
+    $config->{ $self->fallback_version_provider } = $self->_fallback_version_provider_obj->dump_config
+        if $self->_using_fallback_version_provider;
+
     return $config;
 };
 
@@ -71,7 +76,7 @@ around provide_version => sub
     my $version = $self->$orig(@_);
     return $version if defined $version;
 
-    $self->log_debug([ 'no version found in environment or file; falling back to %s', $self->fallback_version_provider ]);
+    $self->log([ 'no version found in environment or file; falling back to %s', $self->fallback_version_provider ]);
     return $self->_fallback_version_provider_obj->provide_version;
 };
 
@@ -101,7 +106,7 @@ Dist::Zilla::Plugin::RewriteVersion::Transitional - ease the transition to [Rewr
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -140,8 +145,8 @@ C<$VERSION> declaration, this plugin will add one. If one is already present,
 it leaves it alone, acting just as
 L<[RewriteVersion]|Dist::Zilla::Plugin::RewriteVersion> would.
 
-You would then use L<[BumpVersionAfterRelease]|Dist::Zilla::Plugin::BumpVersionAfterRelease>
-to increment the C<$VERSION> in the F<.pm> files in the repository, as normal.
+You would then use L<[BumpVersionAfterRelease::Transitional]|Dist::Zilla::Plugin::BumpVersionAfterRelease::Transitional>
+to increment the C<$VERSION> in the F<.pm> files in the repository.
 
 =head1 CONFIGURATION OPTIONS
 
@@ -155,6 +160,9 @@ provider if the version was not already set with the C<V> environment
 variable.  Not used if
 L<Dist::Zilla::Plugin::RewriteVersion/skip_version_provider> is true.
 
+Don't forget to add this plugin as a runtime-requires prerequisite in your
+plugin bundle!
+
 =head1 SUPPORT
 
 =for stopwords irc
